Interface: ElementOptionsByType | Chart.js
Description: Open source HTML5 Charts for your website

# # Interface: ElementOptionsByType<TType>

## # Type parameters

Name | Type
--- | ---
`TType` | extends `ChartType`

## # Properties

### # arc

• arc: `ScriptableAndArrayOptions`<`ArcOptions` & `ArcHoverOptions`, `ScriptableContext`<`TType`>>

#### # Defined in

index.esm.d.ts:2040
(opens new window)

### # bar

• bar: `ScriptableAndArrayOptions`<`BarOptions` & `BarHoverOptions`, `ScriptableContext`<`TType`>>

#### # Defined in

index.esm.d.ts:2041
(opens new window)

### # line

• line: `ScriptableAndArrayOptions`<`LineOptions` & `LineHoverOptions`, `ScriptableContext`<`TType`>>

#### # Defined in

index.esm.d.ts:2042
(opens new window)

### # point

• point: `ScriptableAndArrayOptions`<`PointOptions` & `PointHoverOptions`, `ScriptableContext`<`TType`>>

#### # Defined in

index.esm.d.ts:2043
(opens new window)